@@ -605,7 +605,7 @@ vips_embed_class_init( VipsEmbedClass *class )
 
 	VIPS_ARG_BOXED( class, "background", 12, 
 		_( "Background" ), 
-		_( "Colour for background pixels" ),
+		_( "Color for background pixels" ),
 		VIPS_ARGUMENT_OPTIONAL_INPUT,
 		G_STRUCT_OFFSET( VipsEmbed, background ),
 		VIPS_TYPE_ARRAY_DOUBLE );
@@ -634,7 +634,9 @@ vips_embed_init( VipsEmbed *embed )
  * @background: #VipsArrayDouble colour for edge pixels
  *
  * The opposite of vips_extract_area(): embed @in within an image of size 
- * @width by @height at position @x, @y.  @extend
+ * @width by @height at position @x, @y.  
+ *
+ * @extend
  * controls what appears in the new pels, see #VipsExtend. 
  *
  * See also: vips_extract_area(), vips_insert().
