@@ -79,6 +79,17 @@ im_filename_split( const char *path, char *name, char *mode )
 
 			if( *q == '.' )
 				break;
+
+			/* All the way back to the start? We probably have a
+			 * filename with no extension, eg. "I180:"
+			 */
+			if( q == name )
+				break;
+
+			/* .. or we could hit a dirsep.
+			 */
+			if( *q == G_DIR_SEPARATOR )
+				break;
 		}
 
 	if( *p == ':' ) {
@@ -1137,9 +1148,7 @@ im_copy_swap( IMAGE *in, IMAGE *out )
 {
 	VipsImage *x;
 
-	if( vips_copy( in, &x, 
-		"swap", TRUE, 
-		NULL ) )
+	if( vips_byteswap( in, &x, NULL ) )
 		return( -1 );
 	if( vips_image_write( x, out ) ) {
 		g_object_unref( x );
