@@ -10,6 +10,8 @@
  * 	- pack and unpack rad to scrgb
  * 18/8/14
  * 	- fix conversion to 16-bit RGB, thanks John
+ * 18/6/15
+ * 	- forward progress signals from load
  */
 
 /*
@@ -775,8 +777,14 @@ vips_foreign_load_start( VipsImage *out, void *a, void *b )
 		printf( "vips_foreign_load_start: triggering ->load()\n" );
 #endif /*DEBUG*/
 
-		/* Read the image in.
+		/* Read the image in. This may involve a long computation and
+		 * will finish with load->real holding the decompressed image. 
+		 *
+		 * We want our caller to be able to see this computation on
+		 * @out, so eval signals on ->real need to appear on ->out.
 		 */
+		load->real->progress_signal = load->out;
+
 		if( class->load( load ) ||
 			vips_image_pio_input( load->real ) ) 
 			return( NULL );
@@ -796,6 +804,7 @@ vips_foreign_load_start( VipsImage *out, void *a, void *b )
 		 */
 		vips_image_pipelinev( load->out, load->out->dhint, 
 			load->real, NULL );
+
 	}
 
 	return( vips_region_new( load->real ) );
@@ -1202,6 +1211,9 @@ vips_foreign_convert_saveable( VipsForeignSave *save )
 
 			if( vips_flatten( in, &out, 
 				"background", save->background,
+				"max_alpha", 
+					in->BandFmt == VIPS_FORMAT_USHORT ?
+						65535.0 : 255.0, 
 				NULL ) ) {
 				g_object_unref( in );
 				return( -1 );
@@ -1557,7 +1569,7 @@ vips_foreign_find_save_buffer( const char *name )
 		(VipsSListMap2Fn) vips_foreign_find_save_buffer_sub, 
 		(void *) suffix, NULL )) ) {
 		vips_error( "VipsForeignSave",
-			_( "\"%s\" is not a known file format" ), name );
+			_( "\"%s\" is not a known buffer format" ), name );
 
 		return( NULL );
 	}
