@@ -65,6 +65,11 @@
  * 	- add a "no_subsample" option to disable chroma subsample
  * 9/9/14
  * 	- support "none" as a resolution unit
+ * 8/7/15
+ * 	- omit oversized jpeg markers
+ * 15/7/15
+ * 	- exif tags use @name, not @title
+* 	- set arbitrary exif tags from metadata
  */
 
 /*
@@ -109,6 +114,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <ctype.h>
 #include <setjmp.h>
 #include <math.h>
 
@@ -243,7 +249,7 @@ vips_exif_set_int( ExifData *ed,
 	offset = component * sizeof_component;
 
 	VIPS_DEBUG_MSG( "vips_exif_set_int: %s = %d\n",
-		exif_tag_get_title( entry->tag ), value );
+		exif_tag_get_name( entry->tag ), value );
 
 	if( entry->format == EXIF_FORMAT_SHORT ) 
 		exif_set_short( entry->data + offset, bo, value );
@@ -329,7 +335,7 @@ vips_exif_set_rational( ExifData *ed,
 	offset = component * sizeof_component;
 
 	VIPS_DEBUG_MSG( "vips_exif_set_rational: %s = \"%s\"\n",
-		exif_tag_get_title( entry->tag ), value );
+		exif_tag_get_name( entry->tag ), value );
 
 	if( entry->format == EXIF_FORMAT_RATIONAL ) {
 		ExifRational rv;
@@ -383,7 +389,7 @@ vips_exif_set_double( ExifData *ed,
 	offset = component * sizeof_component;
 
 	VIPS_DEBUG_MSG( "vips_exif_set_double: %s = %g\n",
-		exif_tag_get_title( entry->tag ), value );
+		exif_tag_get_name( entry->tag ), value );
 
 	if( entry->format == EXIF_FORMAT_RATIONAL ) {
 		ExifRational rv;
@@ -421,7 +427,7 @@ typedef void (*write_fn)( ExifData *ed,
 
 /* Write a tag. Update what's there, or make a new one.
  */
-static int
+static void
 write_tag( ExifData *ed, int ifd, ExifTag tag, write_fn fn, void *data )
 {
 	ExifEntry *entry;
@@ -442,8 +448,6 @@ write_tag( ExifData *ed, int ifd, ExifTag tag, write_fn fn, void *data )
 
 		fn( ed, entry, 0, data );
 	}
-
-	return( 0 );
 }
 
 /* This is different, we set the xres/yres from the vips header rather than
@@ -495,16 +499,12 @@ set_exif_resolution( ExifData *ed, VipsImage *im )
 	/* Main image xres/yres/unit are in ifd0. ifd1 has the thumbnail
 	 * xres/yres/unit.
 	 */
-	if( write_tag( ed, 0, EXIF_TAG_X_RESOLUTION, 
-		vips_exif_set_double, (void *) &xres ) ||
-		write_tag( ed, 0, EXIF_TAG_Y_RESOLUTION, 
-			vips_exif_set_double, (void *) &yres ) ||
-		write_tag( ed, 0, EXIF_TAG_RESOLUTION_UNIT, 
-			vips_exif_set_int, (void *) &unit ) ) {
-		vips_error( "VipsJpeg", 
-			"%s", _( "error setting JPEG resolution" ) );
-		return( -1 );
-	}
+	write_tag( ed, 0, EXIF_TAG_X_RESOLUTION, 
+		vips_exif_set_double, (void *) &xres );
+	write_tag( ed, 0, EXIF_TAG_Y_RESOLUTION, 
+		vips_exif_set_double, (void *) &yres );
+	write_tag( ed, 0, EXIF_TAG_RESOLUTION_UNIT, 
+		vips_exif_set_int, (void *) &unit );
 
 	return( 0 );
 }
@@ -517,14 +517,10 @@ set_exif_dimensions( ExifData *ed, VipsImage *im )
 	VIPS_DEBUG_MSG( "set_exif_dimensions: vips size of %d, %d\n",
 		im->Xsize, im->Ysize );
 
-	if( write_tag( ed, 2, EXIF_TAG_PIXEL_X_DIMENSION, 
-		vips_exif_set_int, (void *) &im->Xsize ) ||
-		write_tag( ed, 2, EXIF_TAG_PIXEL_Y_DIMENSION, 
-			vips_exif_set_int, (void *) &im->Ysize ) ) { 
-		vips_error( "VipsJpeg", 
-			"%s", _( "error setting JPEG dimensions" ) );
-		return( -1 );
-	}
+	write_tag( ed, 2, EXIF_TAG_PIXEL_X_DIMENSION, 
+		vips_exif_set_int, (void *) &im->Xsize );
+	write_tag( ed, 2, EXIF_TAG_PIXEL_Y_DIMENSION, 
+		vips_exif_set_int, (void *) &im->Ysize );
 
 	return( 0 );
 }
@@ -578,49 +574,64 @@ vips_exif_from_s( ExifData *ed, ExifEntry *entry, const char *value )
 	}
 }
 
-typedef struct _VipsExif {
-	VipsImage *image;
-	ExifData *ed;
-	ExifContent *content;
-} VipsExif;
-
-static void
-vips_exif_update_entry( ExifEntry *entry, VipsExif *ve )
+static void 
+vips_exif_set_entry( ExifData *ed, ExifEntry *entry, 
+	unsigned long component, void *data )
 {
-	char name[256];
-	const char *value;
+	const char *string = (const char *) data; 
 
-	vips_snprintf( name, 256, "exif-ifd%d-%s", 
-		exif_entry_get_ifd( entry ),
-		exif_tag_get_title( entry->tag ) );
-	if( vips_image_get_typeof( ve->image, name ) ) {
-		(void) vips_image_get_string( ve->image, name, &value );
-		vips_exif_from_s( ve->ed, entry, value ); 
-	}
-	else
-		exif_content_remove_entry( ve->content, entry );
+	vips_exif_from_s( ed, entry, string ); 
 }
 
-static void
-vips_exif_update_content( ExifContent *content, VipsExif *ve )
+static void *
+vips_exif_image_field( VipsImage *image, 
+	const char *field, GValue *value, void *data )
 {
-	ve->content = content;
-        exif_content_foreach_entry( content, 
-		(ExifContentForeachEntryFunc) vips_exif_update_entry, ve );
+	ExifData *ed = (ExifData *) data;
+
+	const char *string;
+	int ifd;
+	const char *p;
+	ExifTag tag;
+
+	if( !vips_isprefix( "exif-ifd", field ) ) 
+		return( NULL );
+
+	/* value must be a string.
+	 */
+	if( vips_image_get_string( image, field, &string ) ) {
+		vips_warn( "VipsJpeg", _( "bad exif meta \"%s\"" ), field );
+		return( NULL ); 
+	}
+
+	p = field + strlen( "exif-ifd" );
+	ifd = atoi( p ); 
+
+	for( ; isdigit( *p ); p++ )
+		;
+	if( *p != '-' ) {
+		vips_warn( "VipsJpeg", _( "bad exif meta \"%s\"" ), field );
+		return( NULL ); 
+	}
+
+	if( !(tag = exif_tag_from_name( p + 1 )) ) {
+		vips_warn( "VipsJpeg", _( "bad exif meta \"%s\"" ), field );
+		return( NULL ); 
+	}
+
+	write_tag( ed, ifd, tag, vips_exif_set_entry, (void *) string );
+
+	return( NULL ); 
 }
 
 static void
 vips_exif_update( ExifData *ed, VipsImage *image )
 {
-	VipsExif ve;
-
 	VIPS_DEBUG_MSG( "vips_exif_update: \n" );
 
-	ve.image = image;
-	ve.ed = ed;
-	exif_data_foreach_content( ed, 
-		(ExifDataForeachContentFunc) vips_exif_update_content, &ve );
+	vips_image_map( image, vips_exif_image_field, ed );
 }
+
 #endif /*HAVE_EXIF*/
 
 static int
@@ -634,12 +645,28 @@ write_blob( Write *write, const char *field, int app )
 			(void *) &data, &data_length ) )
 			return( -1 );
 
+		/* Single jpeg markers can only hold 64kb, large objects must
+		 * be split into multiple markers.
+		 *
+		 * Unfortunately, how this splitting is done depends on the
+		 * data type. For example, ICC and XMP have completely 
+		 * different ways of doing this.
+		 *
+		 * For now, just ignore oversize objects and warn.
+		 */
+		if( data_length > 65530 ) 
+			vips_warn( "VipsJpeg", _( "field \"%s\" is too large "
+				"for a single JPEG marker, ignoring" ), 
+				field );
+		else {
 #ifdef DEBUG
-		printf( "write_blob: attaching %zd bytes of %s\n", 
-			data_length, field );
+			printf( "write_blob: attaching %zd bytes of %s\n", 
+				data_length, field );
 #endif /*DEBUG*/
 
-		jpeg_write_marker( &write->cinfo, app, data, data_length );
+			jpeg_write_marker( &write->cinfo, app, 
+				data, data_length );
+		}
 	}
 
 	return( 0 );
@@ -1287,10 +1314,15 @@ term_destination( j_compress_ptr cinfo )
 	 */
 	if( !(obuf = vips_malloc( NULL, len )) )
 		ERREXIT( cinfo, JERR_FILE_WRITE );
-	*(buf->obuf) = obuf;
-	*(buf->olen) = len;
+	else {
+		/* coverity doesn't know ERREXIT() does not return, so put
+		 * this in an else.
+		 */
+		*(buf->obuf) = obuf;
+		*(buf->olen) = len;
 
-	block_copy( buf->block, obuf );
+		block_copy( buf->block, obuf );
+	}
 }
 
 /* Set dest to one of our objects.
